/*
 * Copyright 2012, Cloudwords, Inc. Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.cloudwords.com/developers/license-1.0 Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language governing permissions and limitations under the
 * License.
 */
package com.cloudwords.api.client.resources;

/**
 * Represents a {@link User}, {@link Vendor}, or set of project followers 
 * (represented as a {@link ProjectFollowers} resource) that are the assignee on a {@link Task} in Cloudwords.
 * 
 * @author mpermana
 * @since 1.4
 */
public class Assignee extends UserOrVendor {

    private ProjectFollowers projectFollowers;
    private Customer customer;


	public ProjectFollowers getProjectFollowers() {
		return projectFollowers;
	}

	public void setProjectFollowers(ProjectFollowers projectFollowers) {
    	if (projectFollowers != null & projectFollowers.getProjectId() != null) {
    		this.projectFollowers = projectFollowers;
    	}
	}

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = super.hashCode();
        result = prime * result + ((customer == null) ? 0 : customer.hashCode());
        result = prime * result + ((projectFollowers == null) ? 0 : projectFollowers.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (!super.equals(obj)) return false;
        if (getClass() != obj.getClass()) return false;
        Assignee other = (Assignee)obj;
        if (customer == null) {
            if (other.customer != null) return false;
        } else if (!customer.equals(other.customer)) return false;
        if (projectFollowers == null) {
            if (other.projectFollowers != null) return false;
        } else if (!projectFollowers.equals(other.projectFollowers)) return false;
        return true;
    }

    @Override
    public String toString() {
        return "Assignee [customer=" + getCustomer() + ", projectFollowers=" + projectFollowers + ", getCustomerUser()="
                + getCustomerUser() + ", getVendor()=" + getVendor() + "]";
    }

    public Customer getCustomer() {
        return customer;
    }

    public void setCustomer(Customer customer) {
        this.customer = customer;
    }

}
