/**
 * 
 */
package com.cloudwords.api.client.resources;

import java.math.BigDecimal;

/**
 * Represents the summary information of a {@link Vendor} provided bid.
 *
 * @author jonathansu
 * @since 1.7
 */
public class BidSummary extends BaseResource {

    private Integer id;
    private CodeAndDisplay status;
    private String description;
    private BigDecimal amount;
    
    /**
     * The unique ID associated with this {@link CustomerBid}
     * @return The unique ID associated with this {@link CustomerBid}
     */
    public Integer getId() {
        return id;
    }
    
    /**
     * Set the unique ID associated with this {@link CustomerBid}
     * @param id The unique ID associated with this {@link CustomerBid}
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * Get the {@link CustomerBid} status.
     * 
     * @return status of this {@link CustomerBid}
     */
    public CodeAndDisplay getStatus() {
        return status;
    }
    
    /**
     * Set the {@link CustomerBid} status. (Note: Bid status is a read-only
     * field with the Cloudwords API - setting a {@link CustomerBid} status and sending it to the API
     * will have no effect.)
     * 
     * @param status of this {@link CustomerBid}
     */
    public void setStatus(CodeAndDisplay status) {
        this.status = status;
    }
    
    /**
     * Get the description provided by the {@link Vendor} for this bid
     * @return The description provided by the {@link Vendor} for this bid
     */
    public String getDescription() {
        return description;
    }
    
    /**
     * Set the description provided by the {@link Vendor} for this bid
     * @param description Set the description provided by the {@link Vendor} for this bid
     */
    public void setDescription(String description) {
        this.description = description;
    }
    
    /**
     * Get the total amount of this {@link CustomerBid} 
     * @return The total amount of this {@link CustomerBid} 
     */
    public BigDecimal getAmount() {
        return amount;
    }
    
    /**
     * Set the total amount of this {@link CustomerBid} 
     * @param amount The total amount of this {@link CustomerBid} 
     */
    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    
}
