/*
 * Copyright 2011, Cloudwords, Inc.
 *
 * Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.cloudwords.com/developers/license-1.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudwords.api.client.resources;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Represents the metadata around a translated file for a given {@link Project} and {@link Language}
 * stored in Cloudwords.
 * 
 * @author jonathansu
 * @since 1.0
 */
public class CloudwordsLanguageFile extends CloudwordsFile {

    private Language lang;
    private CodeAndDisplay status;

    /**
     * Get the target {@link Language} associated with this file.
     * 
     * @return lang
     */
    public Language getLang() {
        return lang;
    }

    /**
     * Set the target {@link Language} associated with this file.
     * 
     * @param lang
     */
    public void setLang(Language lang) {
        this.lang = lang;
    }
    
    /**
     * Get the {@link CloudwordsLanguageFile} status.
     * 
     * @return status of this {@link CloudwordsLanguageFile}
     */
    public CodeAndDisplay getStatus() {
        return status;
    }

    /**
     * Set the {@link CloudwordsLanguageFile} status.
     * 
     * @param status
     *            of this {@link CloudwordsLanguageFile}
     */
    public void setStatus(CodeAndDisplay status) {
        this.status = status;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this).append("id", getId()).append("filename", getFilename())
                .append("contentPath", getContentPath()).append("sizeInKilobytes", getSizeInKilobytes())
                .append("fileContents", getFileContents()).append("createdDate", getCreatedDate())
                .append("path", getPath()).append("lang", lang).append("status", status).toString();
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(getId()).append(getFilename()).append(getContentPath())
                .append(getSizeInKilobytes()).append(getFileContents()).append(getCreatedDate()).append(getPath())
                .append(lang).append(status).hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj == this) {
            return true;
        }
        if (obj.getClass() != getClass()) {
            return false;
        }
        CloudwordsLanguageFile rhs = (CloudwordsLanguageFile)obj;
        return new EqualsBuilder().append(getId(), rhs.getId()).append(getFilename(), rhs.getFilename())
                .append(getContentPath(), rhs.getContentPath()).append(getSizeInKilobytes(), rhs.getSizeInKilobytes())
                .append(getFileContents(), rhs.getFileContents()).append(getCreatedDate(), rhs.getCreatedDate())
                .append(getPath(), rhs.getPath()).append(lang, rhs.lang).append(status, rhs.status).isEquals();
    }
}
