/*
 * Copyright 2012, Cloudwords, Inc. Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.cloudwords.com/developers/license-1.0 Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language governing permissions and limitations under the
 * License.
 */
package com.cloudwords.api.client.resources;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * A convenience struct for a code or status field returned from Cloudwords, which contains the actual
 * code and its human readable display.
 *
 * @author syancey
 * @since 1.5
 */
public class CodeAndDisplay {

    private String display;
    private String code;
    
    public CodeAndDisplay() {}
    
    public CodeAndDisplay(String code) {
        this.code = code;
    }

    /**
     * Get the user-friendly display representation of this {@link CodeAndDisplay} field.
     * 
     * @return user-friendly display
     */
    public String getDisplay() {
        return display;
    }

    /**
     * Set the user-friendly display representation of this {@link CodeAndDisplay} field.
     * 
     * @param display
     *            user-friendly display
     */
    public void setDisplay(String display) {
        this.display = display;
    }

    /**
     * Get the code for {@link CodeAndDisplay} field.
     * 
     * @return code for the {@link CodeAndDisplay} field
     */
    public String getCode() {
        return code;
    }

    /**
     * Set the code for the {@link CodeAndDisplay} field.
     * 
     * @param code
     *            {@link CodeAndDisplay} field code
     */
    public void setCode(String code) {
        this.code = code;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this).append("code", code).append("display", display).toString();
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(code).hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) { return false; }
        if (obj == this) { return true; }
        if (obj.getClass() != getClass()) { return false; }
        CodeAndDisplay rhs = (CodeAndDisplay)obj;
        return new EqualsBuilder().append(code, rhs.code).isEquals();
    }

}
