/*
 * Copyright 2012, Cloudwords, Inc. Licensed under the API LICENSE AGREEMENT, Version 1.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.cloudwords.com/developers/license-1.0 Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language governing permissions and limitations under the
 * License.
 */
package com.cloudwords.api.client.resources;

import java.util.Date;

/**
 * Represents a {@link Task} resource in Cloudwords. 
 * 
 * Translation project management in Cloudwords revolves around a series of tasks that need to be 
 * resolved for the translation project to be successfully completed. Tasks can be generated and 
 * updated automatically by Cloudwords to facilitate the standard translation workflows offered.  
 * Or, a "custom" task can be created at any time to enhance, augment, or inject custom workflow and 
 * steps into a translation project.   
 * 
 * Through the API you can create tasks of type "custom" or "revise_language" (a.k.a. Revision Request).
 * 
 * @author mpermana
 * @since 1.5
 */
public class Task extends BaseResource {

    private int id;
    private BaseProject project;
    private Date createdDate;
    private Date closedDate;
    private CodeAndDisplay type;
    private String name;
    private Assignee assignee;
    private CodeAndDisplay status;
    private Language targetLanguage;
    private String description;
    private Date startDate;
    private Date dueDate;
    private Integer emailReminderDay;

    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    public Date getCreatedDate() {
        return createdDate;
    }

    public void setCreatedDate(Date createdDate) {
        this.createdDate = createdDate;
    }

    public Date getClosedDate() {
        return closedDate;
    }

    public void setClosedDate(Date closedDate) {
        this.closedDate = closedDate;
    }

    public CodeAndDisplay getType() {
        return type;
    }

    public void setType(CodeAndDisplay type) {
        this.type = type;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Assignee getAssignee() {
        return assignee;
    }

    public void setAssignee(Assignee assignee) {
        this.assignee = assignee;
    }

    public CodeAndDisplay getStatus() {
        return status;
    }

    public void setStatus(CodeAndDisplay status) {
        this.status = status;
    }

    public Language getTargetLanguage() {
        return targetLanguage;
    }

    public void setTargetLanguage(Language targetLanguage) {
        this.targetLanguage = targetLanguage;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getDueDate() {
        return dueDate;
    }

    public void setDueDate(Date dueDate) {
        this.dueDate = dueDate;
    }

    public Integer getEmailReminderDay() {
        return emailReminderDay;
    }

    public void setEmailReminderDay(Integer emailReminderDay) {
        this.emailReminderDay = emailReminderDay;
    }

    public BaseProject getProject() {
        return project;
    }

    public void setProject(BaseProject project) {
        this.project = project;
    }

}
