/**
 * 
 */
package com.cloudwords.api.client.resources;

import java.util.List;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * Represents {@link Vendor}'s view of a bid provided for a 
 * given Cloudwords {@link Project}.
 * 
 * @author jonathansu
 * @since 1.7
 */
public class VendorBid extends BidSummary {

    private List<BidItem> bidItems;
    
    /**
     * Get the {@link BidItem} provided by the {@link Vendor} for this bid
     * @return The {@link BidItem} provided by the {@link Vendor} for this bid
     */
    public List<BidItem> getBidItems() {
        return bidItems;
    }

    /**
     * Set the {@link BidItem} provided by the {@link Vendor} for this bid
     * @param bidItems Set the {@link BidItem} provided by the {@link Vendor} for this bid
     */
    public void setBidItems(List<BidItem> bidItems) {
        this.bidItems = bidItems;
    }
    
    @Override
    public String toString() {
        return new ToStringBuilder(this).append("id", getId()).append("status", getStatus())
                .append("description", getDescription()).append("amount", getAmount()).append("path", getPath()).toString();
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(getId()).append(getStatus()).append(getDescription()).append(getAmount())
                .append(getPath()).hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj == this) {
            return true;
        }
        if (obj.getClass() != getClass()) {
            return false;
        }
        CustomerBid rhs = (CustomerBid)obj;
        return new EqualsBuilder().append(getId(), rhs.getId()).append(getStatus(), rhs.getStatus())
                .append(getDescription(), rhs.getDescription()).append(getAmount(), rhs.getAmount()).append(getPath(), rhs.getPath()).isEquals();
    }
}
