package com.cloudwords.api.client.resources;

/**
 * Represents a webhook in Cloudwords. A webhook can be used to be notified of events as they occur in Cloudwords.
 * 
 * @author jasonbuchanan
 * @since 1.15
 */
public class Webhook {
    private Integer id;
    private String uri;
    private Integer entityId;
    private CodeAndDisplay entityType;
    private String contextId;
    private CodeAndDisplay contextType;
    private CodeAndDisplay eventType;

    /**
     * Get the Cloudwords {@link Webhook} ID.
     * 
     * @return id of this {@link Webhook}
     */
    public Integer getId() {
        return id;
    }

    /**
     * Set the Cloudwords {@link Webhook} ID.
     * 
     * @param id of this {@link Webhook}
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * Get the uri of this {@link Webhook}.
     * 
     * @return uri of this {@link Webhook}
     */
    public String getUri() {
        return uri;
    }

    /**
     * Set the uri of this {@link Webhook}.
     * 
     * @param uri of this {@link Webhook}
     */
    public void setUri(String uri) {
        this.uri = uri;
    }

    /**
     * Get the entity id for this {@link Webhook}. This is the id of a {@link Project} in Cloudwords.
     * 
     * @return entityId for this {@link Webhook}
     */
    public Integer getEntityId() {
        return entityId;
    }

    /**
     * Set the entity id for this {@link Webhook}. This is the id of a {@link Project} in Cloudwords.
     * 
     * @param entityId for this {@link Webhook}
     */
    public void setEntityId(Integer entityId) {
        this.entityId = entityId;
    }

    /**
     * Get the entity type for this {@link Webhook}. 
     * 
     * @return entityType for this {@link Webhook}
     */
    public CodeAndDisplay getEntityType() {
        return entityType;
    }

    /**
     * Set the entity type of this {@link Webhook}. Currently, the only valid value is PROJECT.
     * 
     * @param entityType of this {@link Webhook}
     */
    public void setEntityType(CodeAndDisplay entityType) {
        this.entityType = entityType;
    }

    /**
     * Get the context id of this {@link Webhook}.
     * 
     * @return contextId of this {@link Webhook}
     */
    public String getContextId() {
        return contextId;
    }

    /**
     * Set the context id of this {@link Webhook}.
     * 
     * @param contextId of this {@link Webhook}
     */
    public void setContextId(String contextId) {
        this.contextId = contextId;
    }

    /**
     * Get the context type of this {@link Webhook}.
     * 
     * @return contextType of this {@link Webhook}
     */
    public CodeAndDisplay getContextType() {
        return contextType;
    }

    /**
     * Set the context type of this {@link Webhook}.
     * 
     * @param contextType of this {@link Webhook}
     */
    public void setContextType(CodeAndDisplay contextType) {
        this.contextType = contextType;
    }

    /**
     * Get the event type of this {@link Webhook}.
     * 
     * @return eventType of this {@link Webhook}
     */
    public CodeAndDisplay getEventType() {
        return eventType;
    }

    /**
     * Set the event type of this {@link Webhook}.
     * 
     * @param eventType of this {@link Webhook}
     */
    public void setEventType(CodeAndDisplay eventType) {
        this.eventType = eventType;
    }

}
